package cn.estsh.i3plus.pojo.wms.bean;

import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.ColumnDefault;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

/**
 * @Description : 库存移动单条码信息
 * @Reference :
 * @Author : silliter.yuan
 * @CreateDate : 2018-11-06 15:58
 * @Modify:
 **/
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Table(name="WMS_MOVE_SN", indexes = {
        @Index(columnList = "PART_NO"),
        @Index(columnList = "ORDER_NO"),
        @Index(columnList = "SN"),
        @Index(columnList = "ORGANIZE_CODE")
})
@Api("库存移动单条码信息")
public class WmsMoveSn extends BaseBean {

    @Column(name="ORDER_NO")
    @ApiParam("单号")
    public String orderNo;

    @Column(name="ITEM")
    @ApiParam("行号")
    public Integer item;

    @Column(name="PART_NO")
    @ApiParam("物料编码")
    public String partNo;

    @Column(name="PART_NAME_RDD")
    @ApiParam("物料名称")
    public String partNameRdd;

    @Column(name="UNIT")
    @ApiParam(value = "单位")
    public String unit;

    @Column(name="SN")
    @ApiParam("条码")
    public String sn;

    @Column(name="CSN")
    @ApiParam("客户条码")
    public String csn;

    /**
     * 状态:1=创建,10=待处理,20=已处理
     */
    @Column(name="ITEM_STATUS")
    @ApiParam(value = "状态", example = "1")
    public Integer itemStatus;

    @Column(name="REMARK")
    @ApiParam("备注")
    public String remark;

    @Column(name="LOT_NO")
    @ApiParam("批次编号")
    public String lotNo;

    @Column(name="PACKAGE_NO")
    @ApiParam("容器编号")
    public String packAgeNo;

    @Column(name="SRC_QTY")
    @ColumnDefault("0")
    @ApiParam(value = "源数量", example = "0")
    public Double srcQty;

    @Column(name="SRC_WH_NO")
    @ApiParam("源仓库代码")
    public String srcWhNo;

    @Column(name="SRC_ZONE_NO")
    @ApiParam("源存储区代码")
    public String srcZoneNo;

    @Column(name="SRC_LOCATE_NO")
    @ApiParam("源库位代码")
    public String srcLocateNo;

    @Column(name="DEST_WH_NO")
    @ApiParam("目标仓库代码")
    public String destWhNo;

    @Column(name="DEST_ZONE_NO")
    @ApiParam("目标存储区代码")
    public String destZoneNo;

    @Column(name="DEST_LOCATE_NO")
    @ApiParam("目标库位代码")
    public String destLocateNo;

    @ApiParam("待上架箱数")
    @Transient
    private Long waitingCounts;

    @ApiParam("已上架箱数")
    @Transient
    private Long finishedCounts;

    @Column(name="DEST_QTY")
    @ColumnDefault("0")
    @ApiParam(value = "目标数量", example = "0")
    public Double destQty;

    @Column(name="QTY")
    @ColumnDefault("0")
    @ApiParam(value = "数量", example = "0")
    public Double qty;

    @Column(name="SRC_QC_STATUS")
    @ApiParam(value = "源质量状态", example = "1")
    public Integer srcQcStatus;

    @Column(name="SRC_SN_STATUS")
    @ApiParam(value = "源条码状态", example = "1")
    public Integer srcSnStatus;

    @Column(name="DEST_QC_STATUS")
    @ApiParam(value = "目的质量状态", example = "1")
    public Integer descQcStatus;

    @Column(name="DEST_SN_STATUS")
    @ApiParam(value = "目的条码状态", example = "1")
    public Integer destSnStatus;

    @Column(name="DATE_CODE")
    @ApiParam("生产日期")
    public String dateCode;

    @Column(name="FIX_LOT_NO")
    @ApiParam("特殊批次")
    public String fixLotNo;



    @Transient
    @ApiParam("业务类型编码")
    private String busiTypeCode;


    @Transient
    @ApiParam(value = "交易类型代码")
    private String transTypeCode;

    @Transient
    @ApiParam("关联单号")
    public String refSrc;

    @Transient
    @ApiParam("erp库存地")
    private String ZoneNo;

    @Transient
    @ApiParam("供应商编码")
    private String vendorNo;

    @Transient
    @ApiParam("交易类型名称")
    private String transTypeName;

    public WmsMoveSn(){}

    public WmsMoveSn(String partNo, Long finishedCounts ,Long waitingCounts){
        this.partNo = partNo;
        this.waitingCounts = waitingCounts;
        this.finishedCounts = finishedCounts;
    }

    public Long getWaitingCounts() {
        return waitingCounts == null ? 0L : this.waitingCounts;
    }

    public Long getFinishedCounts() {
        return finishedCounts == null ? 0L : this.finishedCounts;
    }

    public WmsMoveSn(String partNo, String partNameRdd, Double destQty,String busiTypeCode,  String transTypeCode, String refSrc) {
        this.partNo = partNo;
        this.partNameRdd = partNameRdd;
        this.destQty = destQty;
        this.busiTypeCode = busiTypeCode;
        this.transTypeCode = transTypeCode;
        this.refSrc = refSrc;
    }
    public WmsMoveSn(String partNo, String partNameRdd, Double destQty,String transTypeCode, String refSrc) {
        this.partNo = partNo;
        this.partNameRdd = partNameRdd;
        this.destQty = destQty;
        this.transTypeCode = transTypeCode;
        this.refSrc = refSrc;
    }
    public  WmsMoveSn( String organizeCode,String orderNo,Integer item,String partNo,String partNameRdd,
            String transTypeCode,String transTypeName,Integer itemStatus,String unit, String srcLocateNo,String destLocateNo,Double srcQty,Double destQty,Integer srcQcStatus,Integer descQcStatus,Integer srcSnStatus,
            Integer destSnStatus, String lotNo,String dateCode){
            this.organizeCode=organizeCode;
            this.orderNo=orderNo;
            this.item=item;
            this.partNo=partNo;
            this.partNameRdd=partNameRdd;
            this.transTypeCode=transTypeCode;
            this.transTypeName=transTypeName;
            this.itemStatus=itemStatus;
            this.unit=unit;
            this.srcLocateNo=srcLocateNo;
            this.destLocateNo=destLocateNo;
            this.srcQty=srcQty;
            this.srcQty=srcQty;
            this.destQty=destQty;
            this.srcQcStatus=srcQcStatus;
            this.descQcStatus=descQcStatus;
            this.srcSnStatus=srcSnStatus;
            this.destSnStatus=destSnStatus;
            this.lotNo=lotNo;
            this.dateCode=dateCode;

}
}
